@@ -11,7 +11,9 @@ pub mod dependencies
   pub use ::for_each;
 }
 
-/// Several macro to encourage write readable code.
+/// Several macro on functions.
+pub mod func;
+/// Several macro to encourage to write indexed code to improve readibility.
 pub mod impls;
 
 /* xxx2 : use name protected */
@@ -37,6 +39,7 @@ pub mod exposed
 {
   pub use super::prelude::*;
   pub use super::impls::exposed::*;
+  pub use super::func::exposed::*;
   pub use super::dependencies::for_each::exposed::*;
 }
 
@@ -45,5 +48,6 @@ pub mod prelude
 {
   pub use literally::*;
   pub use super::impls::prelude::*;
+  pub use super::func::prelude::*;
   pub use super::dependencies::for_each::prelude::*;
 }
